summaryrefslogtreecommitdiffstats
path: root/kexi/plugins/forms
diff options
context:
space:
mode:
Diffstat (limited to 'kexi/plugins/forms')
-rw-r--r--kexi/plugins/forms/kexiactionselectiondialog.cpp12
-rw-r--r--kexi/plugins/forms/kexidataprovider.cpp2
-rw-r--r--kexi/plugins/forms/kexidbfactory.cpp16
-rw-r--r--kexi/plugins/forms/kexidbtextwidgetinterface.cpp6
-rw-r--r--kexi/plugins/forms/kexidbtextwidgetinterface.h2
-rw-r--r--kexi/plugins/forms/kexiformeventhandler.cpp4
-rw-r--r--kexi/plugins/forms/kexiformmanager.cpp2
-rw-r--r--kexi/plugins/forms/kexiformpart.cpp2
-rw-r--r--kexi/plugins/forms/kexiformscrollview.cpp14
-rw-r--r--kexi/plugins/forms/kexiformscrollview.h14
-rw-r--r--kexi/plugins/forms/kexiformview.cpp20
-rw-r--r--kexi/plugins/forms/kexiformview.h2
-rw-r--r--kexi/plugins/forms/widgets/kexidbautofield.cpp2
-rw-r--r--kexi/plugins/forms/widgets/kexidbcombobox.cpp4
-rw-r--r--kexi/plugins/forms/widgets/kexidbcombobox.h2
-rw-r--r--kexi/plugins/forms/widgets/kexidbform.cpp28
-rw-r--r--kexi/plugins/forms/widgets/kexidbimagebox.cpp34
-rw-r--r--kexi/plugins/forms/widgets/kexidbimagebox.h8
-rw-r--r--kexi/plugins/forms/widgets/kexidblabel.cpp14
-rw-r--r--kexi/plugins/forms/widgets/kexidblineedit.cpp4
-rw-r--r--kexi/plugins/forms/widgets/kexidbtextedit.cpp2
-rw-r--r--kexi/plugins/forms/widgets/kexiframe.h2
-rw-r--r--kexi/plugins/forms/widgets/kexiframeutils_p.cpp4
23 files changed, 100 insertions, 100 deletions
diff --git a/kexi/plugins/forms/kexiactionselectiondialog.cpp b/kexi/plugins/forms/kexiactionselectiondialog.cpp
index 921432b6..a20dbe21 100644
--- a/kexi/plugins/forms/kexiactionselectiondialog.cpp
+++ b/kexi/plugins/forms/kexiactionselectiondialog.cpp
@@ -352,12 +352,12 @@ public:
msg = TQString();
// hardcoded, but it's not that bad
else if (actionType=="macro")
- msg = i18n("&Select macro to be executed after clicking \"%1\" button:").tqarg(actionWidgetName);
+ msg = i18n("&Select macro to be executed after clicking \"%1\" button:").arg(actionWidgetName);
else if (actionType=="script")
- msg = i18n("&Select script to be executed after clicking \"%1\" button:").tqarg(actionWidgetName);
+ msg = i18n("&Select script to be executed after clicking \"%1\" button:").arg(actionWidgetName);
//default: table/query/form/report...
else
- msg = i18n("&Select object to be opened after clicking \"%1\" button:").tqarg(actionWidgetName);
+ msg = i18n("&Select object to be opened after clicking \"%1\" button:").arg(actionWidgetName);
selectActionToBeExecutedLbl->setText(msg);
}
@@ -587,7 +587,7 @@ void KexiActionSelectionDialog::slotActionCategorySelected(TQListViewItem* item)
TQVBoxLayout *vlyr = new TQVBoxLayout(d->kactionPageWidget, 0, KDialog::spacingHint());
d->kactionListView = new KActionsListView(d->kactionPageWidget, d->mainWin);
d->kactionListView->init();
- TQLabel *lbl = new TQLabel(d->kactionListView, selectActionToBeExecutedMsg.tqarg(d->actionWidgetName),
+ TQLabel *lbl = new TQLabel(d->kactionListView, selectActionToBeExecutedMsg.arg(d->actionWidgetName),
d->kactionPageWidget);
lbl->setAlignment(TQt::AlignTop|TQt::AlignLeft|TQt::WordBreak);
lbl->setMinimumHeight(lbl->fontMetrics().height()*2);
@@ -613,7 +613,7 @@ void KexiActionSelectionDialog::slotActionCategorySelected(TQListViewItem* item)
d->currentFormActionsPageWidget, d->mainWin);
d->currentFormActionsListView->init();
TQLabel *lbl = new TQLabel(d->currentFormActionsListView,
- selectActionToBeExecutedMsg.tqarg(d->actionWidgetName), d->currentFormActionsPageWidget);
+ selectActionToBeExecutedMsg.arg(d->actionWidgetName), d->currentFormActionsPageWidget);
lbl->setAlignment(TQt::AlignTop|TQt::AlignLeft|TQt::WordBreak);
lbl->setMinimumHeight(lbl->fontMetrics().height()*2);
vlyr->addWidget(lbl);
@@ -696,7 +696,7 @@ KexiFormEventAction::ActionData KexiActionSelectionDialog::currentAction() const
KexiPart::Info* partInfo = partItem ? Kexi::partManager().infoForMimeType( partItem->mimeType() ) : 0;
if (partInfo) {
// opening or executing: table:name, query:name, form:name, macro:name, script:name, etc.
- data.string = TQString("%1:%2").tqarg(partInfo->objectName()).tqarg(partItem->name());
+ data.string = TQString("%1:%2").arg(partInfo->objectName()).arg(partItem->name());
data.option = actionToExecute->data;
return data;
}
diff --git a/kexi/plugins/forms/kexidataprovider.cpp b/kexi/plugins/forms/kexidataprovider.cpp
index 8ae592d9..1a6df899 100644
--- a/kexi/plugins/forms/kexidataprovider.cpp
+++ b/kexi/plugins/forms/kexidataprovider.cpp
@@ -113,7 +113,7 @@ void KexiFormDataProvider::fillDataItems(KexiTableItem& row, bool cursorAtNewRow
kexipluginsdbg << "fill data of '" << itemIface->dataSource() << "' at idx=" << it.data()
<< " data=" << value << (indexForVisibleLookupValue!=-1
? TQString(" SPECIAL: indexForVisibleLookupValue=%1 visibleValue=%2")
- .tqarg(indexForVisibleLookupValue).tqarg(visibleLookupValue.toString())
+ .arg(indexForVisibleLookupValue).arg(visibleLookupValue.toString())
: TQString())
<< endl;
const bool displayDefaultValue = cursorAtNewRow && (value.isNull() && visibleLookupValue.isNull())
diff --git a/kexi/plugins/forms/kexidbfactory.cpp b/kexi/plugins/forms/kexidbfactory.cpp
index e882c082..d87b31c5 100644
--- a/kexi/plugins/forms/kexidbfactory.cpp
+++ b/kexi/plugins/forms/kexidbfactory.cpp
@@ -462,7 +462,7 @@ KexiDBFactory::startEditing(const TQCString &classname, TQWidget *w, KFormDesign
//! just inherited StdWidgetFactory::clearWidgetContent() should be called
KLineEdit *lineedit = static_cast<KLineEdit*>(w);
createEditor(classname, lineedit->text(), lineedit, container,
- lineedit->tqgeometry(), lineedit->tqalignment(), true);
+ lineedit->geometry(), lineedit->alignment(), true);
return true;
}
if(classname == "KexiDBTextEdit")
@@ -471,7 +471,7 @@ KexiDBFactory::startEditing(const TQCString &classname, TQWidget *w, KFormDesign
//! just inherited StdWidgetFactory::clearWidgetContent() should be called
KTextEdit *textedit = static_cast<KTextEdit*>(w);
createEditor(classname, textedit->text(), textedit, container,
- textedit->tqgeometry(), textedit->tqalignment(), true, true);
+ textedit->geometry(), textedit->alignment(), true, true);
//copy a few properties
KTextEdit *ed = dynamic_cast<KTextEdit *>( editor(w) );
ed->setWrapPolicy(textedit->wrapPolicy());
@@ -502,8 +502,8 @@ KexiDBFactory::startEditing(const TQCString &classname, TQWidget *w, KFormDesign
else
{
createEditor(classname, label->text(), label, container,
- label->tqgeometry(), label->tqalignment(),
- false, label->tqalignment() & TQt::WordBreak /*multiline*/);
+ label->geometry(), label->alignment(),
+ false, label->alignment() & TQt::WordBreak /*multiline*/);
}
return true;
}
@@ -529,12 +529,12 @@ KexiDBFactory::startEditing(const TQCString &classname, TQWidget *w, KFormDesign
if(static_cast<KexiDBAutoField*>(w)->hasAutoCaption())
return false; // caption is auto, abort editing
TQLabel *label = static_cast<KexiDBAutoField*>(w)->label();
- createEditor(classname, label->text(), label, container, label->tqgeometry(), label->tqalignment());
+ createEditor(classname, label->text(), label, container, label->geometry(), label->alignment());
return true;
}
else if (classname == "KexiDBCheckBox") {
KexiDBCheckBox *cb = static_cast<KexiDBCheckBox*>(w);
- TQRect r( cb->tqgeometry() );
+ TQRect r( cb->geometry() );
r.setLeft( r.left() + 2 + cb->tqstyle().subRect( TQStyle::SR_CheckBoxIndicator, cb ).width() );
createEditor(classname, cb->text(), cb, container, r, TQt::AlignAuto);
return true;
@@ -679,7 +679,7 @@ KexiDBFactory::changeText(const TQString &text)
changeProperty("caption", text, form);
return true;
}
- //! \todo check field's tqgeometry
+ //! \todo check field's geometry
return false;
}
@@ -690,7 +690,7 @@ KexiDBFactory::resizeEditor(TQWidget *editor, TQWidget *w, const TQCString &clas
//TQPoint p = widget->pos();
if(classname == "KexiDBAutoField")
- editor->setGeometry( static_cast<KexiDBAutoField*>(w)->label()->tqgeometry() );
+ editor->setGeometry( static_cast<KexiDBAutoField*>(w)->label()->geometry() );
}
void
diff --git a/kexi/plugins/forms/kexidbtextwidgetinterface.cpp b/kexi/plugins/forms/kexidbtextwidgetinterface.cpp
index 3c20510e..68dea85f 100644
--- a/kexi/plugins/forms/kexidbtextwidgetinterface.cpp
+++ b/kexi/plugins/forms/kexidbtextwidgetinterface.cpp
@@ -43,7 +43,7 @@ void KexiDBTextWidgetInterface::setColumnInfo(KexiDB::QueryColumnInfo* cinfo, TQ
}
}
-void KexiDBTextWidgetInterface::paint( TQFrame *w, TQPainter* p, bool textIsEmpty, int tqalignment, bool hasFocus )
+void KexiDBTextWidgetInterface::paint( TQFrame *w, TQPainter* p, bool textIsEmpty, int alignment, bool hasFocus )
{
KexiFormDataItemInterface *dataItemIface = dynamic_cast<KexiFormDataItemInterface*>(w);
KexiDB::QueryColumnInfo *columnInfo = dataItemIface ? dataItemIface->columnInfo() : 0;
@@ -57,7 +57,7 @@ void KexiDBTextWidgetInterface::paint( TQFrame *w, TQPainter* p, bool textIsEmpt
}
KexiDisplayUtils::paintAutonumberSign(*m_autonumberDisplayParameters, p,
2 + margin + w->margin(), margin, w->width() - margin*2 -2-2,
- w->height() - margin*2 -2, tqalignment, hasFocus);
+ w->height() - margin*2 -2, alignment, hasFocus);
}
}
}
@@ -66,6 +66,6 @@ void KexiDBTextWidgetInterface::event( TQEvent * e, TQWidget *w, bool textIsEmpt
{
if (e->type()==TQEvent::FocusIn || e->type()==TQEvent::FocusOut) {
if (m_autonumberDisplayParameters && textIsEmpty)
- w->tqrepaint();
+ w->repaint();
}
}
diff --git a/kexi/plugins/forms/kexidbtextwidgetinterface.h b/kexi/plugins/forms/kexidbtextwidgetinterface.h
index 6e0299c0..17382e31 100644
--- a/kexi/plugins/forms/kexidbtextwidgetinterface.h
+++ b/kexi/plugins/forms/kexidbtextwidgetinterface.h
@@ -40,7 +40,7 @@ class KEXIFORMUTILS_EXPORT KexiDBTextWidgetInterface
void setColumnInfo(KexiDB::QueryColumnInfo* cinfo, TQWidget *w);
//! Called from paintEvent( TQPaintEvent *pe ) method of the data aware widget.
- void paint( TQFrame *w, TQPainter *p, bool textIsEmpty, int tqalignment, bool hasFocus );
+ void paint( TQFrame *w, TQPainter *p, bool textIsEmpty, int alignment, bool hasFocus );
//! Called from event( TQEvent * e ) method of the data aware widget.
void event( TQEvent * e, TQWidget *w, bool textIsEmpty );
diff --git a/kexi/plugins/forms/kexiformeventhandler.cpp b/kexi/plugins/forms/kexiformeventhandler.cpp
index 4e066bd6..55e999db 100644
--- a/kexi/plugins/forms/kexiformeventhandler.cpp
+++ b/kexi/plugins/forms/kexiformeventhandler.cpp
@@ -56,7 +56,7 @@ KexiPart::Info* KexiFormEventAction::ActionData::decodeString(
return 0;
KexiPart::Info *info = 0;
if (_actionType!="kaction" && _actionType!="currentForm") {
- info = Kexi::partManager().infoForMimeType( TQString("kexi/%1").tqarg(_actionType) );
+ info = Kexi::partManager().infoForMimeType( TQString("kexi/%1").arg(_actionType) );
if (!info)
return 0;
}
@@ -85,7 +85,7 @@ void KexiFormEventAction::activate()
if (!project)
return;
KexiPart::Part* part = Kexi::partManager().partForMimeType(
- TQString("kexi/%1").tqarg(m_actionName) );
+ TQString("kexi/%1").arg(m_actionName) );
if (!part)
return;
KexiPart::Item* item = project->item( part->info(), m_objectName );
diff --git a/kexi/plugins/forms/kexiformmanager.cpp b/kexi/plugins/forms/kexiformmanager.cpp
index 9674f4fe..8c0c66e7 100644
--- a/kexi/plugins/forms/kexiformmanager.cpp
+++ b/kexi/plugins/forms/kexiformmanager.cpp
@@ -112,7 +112,7 @@ void KexiFormManager::setFormDataSource(const TQCString& mime, const TQCString&
propValues.insert("dataSource", name);
propValues.insert("dataSourceMimeType", mime);
KFormDesigner::CommandGroup *group
- = new KFormDesigner::CommandGroup(i18n("Set Form's Data Source to \"%1\"").tqarg(name.data()), propertySet());
+ = new KFormDesigner::CommandGroup(i18n("Set Form's Data Source to \"%1\"").arg(name.data()), propertySet());
propertySet()->createPropertyCommandsInDesignMode(formWidget, propValues, group, true /*addToActiveForm*/);
}
diff --git a/kexi/plugins/forms/kexiformpart.cpp b/kexi/plugins/forms/kexiformpart.cpp
index 84c50efd..9d8017d8 100644
--- a/kexi/plugins/forms/kexiformpart.cpp
+++ b/kexi/plugins/forms/kexiformpart.cpp
@@ -277,7 +277,7 @@ KexiFormPart::generateForm(KexiDB::FieldList *list, TQDomDocument &domDoc)
TQDomElement lNameProperty = domDoc.createElement("property");
lNameProperty.setAttribute("name", "name");
TQDomElement lType = domDoc.createElement("cstring");
- TQDomText lClassN = domDoc.createTextNode(TQString("l%1").tqarg(list->field(i)->name()));
+ TQDomText lClassN = domDoc.createTextNode(TQString("l%1").arg(list->field(i)->name()));
lType.appendChild(lClassN);
lNameProperty.appendChild(lType);
lclass.appendChild(lNameProperty);
diff --git a/kexi/plugins/forms/kexiformscrollview.cpp b/kexi/plugins/forms/kexiformscrollview.cpp
index 790064e2..b4b58f70 100644
--- a/kexi/plugins/forms/kexiformscrollview.cpp
+++ b/kexi/plugins/forms/kexiformscrollview.cpp
@@ -150,9 +150,9 @@ void KexiFormScrollView::moveToFirstRecordRequested()
selectFirstRow();
}
-void KexiFormScrollView::clearColumnsInternal(bool tqrepaint)
+void KexiFormScrollView::clearColumnsInternal(bool repaint)
{
- Q_UNUSED( tqrepaint );
+ Q_UNUSED( repaint );
//! @todo
}
@@ -349,7 +349,7 @@ void KexiFormScrollView::slotRowRepaintRequested(KexiTableItem& item)
}
/*void KexiFormScrollView::slotAboutToDeleteRow(KexiTableItem& item,
- KexiDB::ResultInfo* result, bool tqrepaint)
+ KexiDB::ResultInfo* result, bool repaint)
{
//! @todo
}*/
@@ -359,18 +359,18 @@ void KexiFormScrollView::slotRowRepaintRequested(KexiTableItem& item)
//! @todo
}*/
-void KexiFormScrollView::slotRowInserted(KexiTableItem *item, bool tqrepaint)
+void KexiFormScrollView::slotRowInserted(KexiTableItem *item, bool repaint)
{
Q_UNUSED( item );
- Q_UNUSED( tqrepaint );
+ Q_UNUSED( repaint );
//! @todo
}
-void KexiFormScrollView::slotRowInserted(KexiTableItem *item, uint row, bool tqrepaint)
+void KexiFormScrollView::slotRowInserted(KexiTableItem *item, uint row, bool repaint)
{
Q_UNUSED( item );
Q_UNUSED( row );
- Q_UNUSED( tqrepaint );
+ Q_UNUSED( repaint );
//! @todo
}
diff --git a/kexi/plugins/forms/kexiformview.cpp b/kexi/plugins/forms/kexiformview.cpp
index 3b7968de..36a64db7 100644
--- a/kexi/plugins/forms/kexiformview.cpp
+++ b/kexi/plugins/forms/kexiformview.cpp
@@ -350,7 +350,7 @@ void KexiFormView::updateValuesForSubproperties()
if (meta) {
// Special case: the property value of type enum (set) but is saved as a string list,
// not as int, so we need to translate it to int. It's been created as such
- // by FormIO::readPropertyValue(). Example: "tqalignment" property.
+ // by FormIO::readPropertyValue(). Example: "alignment" property.
if (meta->isSetType() && subpropIt.data().type()==TQVariant::StringList) {
TQStrList keys;
const TQStringList list( subpropIt.data().toStringList() );
@@ -1115,7 +1115,7 @@ KexiFormView::insertAutoFields(const TQString& sourceMimeType, const TQString& s
// KFormDesigner::WidgetList* prevSelection = form()->selectedWidgets();
KFormDesigner::WidgetList widgetsToSelect;
KFormDesigner::CommandGroup *group = new KFormDesigner::CommandGroup(
- fields.count()==1 ? i18n("Insert AutoField widget") : i18n("Insert %1 AutoField widgets").tqarg(fields.count()),
+ fields.count()==1 ? i18n("Insert AutoField widget") : i18n("Insert %1 AutoField widgets").arg(fields.count()),
KFormDesigner::FormManager::self()->propertySet()
);
@@ -1191,10 +1191,10 @@ KexiFormView::insertAutoFields(const TQString& sourceMimeType, const TQString& s
}
if (widgetsToSelect.last()) {
//resize form if needed
- TQRect oldFormRect( m_dbform->tqgeometry() );
+ TQRect oldFormRect( m_dbform->geometry() );
TQRect newFormRect( oldFormRect );
- newFormRect.setWidth(TQMAX(m_dbform->width(), widgetsToSelect.last()->tqgeometry().right()+1));
- newFormRect.setHeight(TQMAX(m_dbform->height(), widgetsToSelect.last()->tqgeometry().bottom()+1));
+ newFormRect.setWidth(TQMAX(m_dbform->width(), widgetsToSelect.last()->geometry().right()+1));
+ newFormRect.setHeight(TQMAX(m_dbform->height(), widgetsToSelect.last()->geometry().bottom()+1));
if (newFormRect != oldFormRect) {
//1. resize by hand
m_dbform->setGeometry( newFormRect );
@@ -1205,8 +1205,8 @@ KexiFormView::insertAutoFields(const TQString& sourceMimeType, const TQString& s
group->addCommand(resizeFormCommand, true/*will be executed on CommandGroup::execute()*/);
}
- //remember tqgeometry of the last inserted widget
- m_widgetGeometryForRecentInsertAutoFields = widgetsToSelect.last()->tqgeometry();
+ //remember geometry of the last inserted widget
+ m_widgetGeometryForRecentInsertAutoFields = widgetsToSelect.last()->geometry();
}
//eventually, add entire command group to active form
@@ -1217,11 +1217,11 @@ KexiFormView::insertAutoFields(const TQString& sourceMimeType, const TQString& s
//enable proper REDO usage
group->resetAllowExecuteFlags();
- m_scrollView->tqrepaint();
- m_scrollView->viewport()->tqrepaint();
+ m_scrollView->repaint();
+ m_scrollView->viewport()->repaint();
m_scrollView->repaintContents();
m_scrollView->updateContents();
- m_scrollView->clipper()->tqrepaint();
+ m_scrollView->clipper()->repaint();
m_scrollView->refreshContentsSize();
//select all inserted widgets, if multiple
diff --git a/kexi/plugins/forms/kexiformview.h b/kexi/plugins/forms/kexiformview.h
index 8bc1cb79..f269abf7 100644
--- a/kexi/plugins/forms/kexiformview.h
+++ b/kexi/plugins/forms/kexiformview.h
@@ -218,7 +218,7 @@ class KEXIFORMUTILS_EXPORT KexiFormView : public KexiDataAwareView
TQGuardedPtr<TQWidget> m_setFocusInternalOnce;
- /*! Stores tqgeometry of widget recently inserted using insertAutoFields() method.
+ /*! Stores geometry of widget recently inserted using insertAutoFields() method.
having this information, we'r eable to compute position for a newly
inserted widget in insertAutoFields() is such position has not been specified.
(the position is specified when a widget is inserted with mouse drag & dropping
diff --git a/kexi/plugins/forms/widgets/kexidbautofield.cpp b/kexi/plugins/forms/widgets/kexidbautofield.cpp
index 939d9b91..3a8e8453 100644
--- a/kexi/plugins/forms/widgets/kexidbautofield.cpp
+++ b/kexi/plugins/forms/widgets/kexidbautofield.cpp
@@ -232,7 +232,7 @@ KexiDBAutoField::setLabelPosition(LabelPosition position)
m_subwidget->show();
//! \todo support right-to-left tqlayout where positions are inverted
if (position==Top || position==Left) {
- int align = d->label->tqalignment();
+ int align = d->label->alignment();
if(position == Top) {
d->tqlayout = (TQBoxLayout*) new TQVBoxLayout(this);
align |= AlignVertical_Mask;
diff --git a/kexi/plugins/forms/widgets/kexidbcombobox.cpp b/kexi/plugins/forms/widgets/kexidbcombobox.cpp
index 231003cf..db56b550 100644
--- a/kexi/plugins/forms/widgets/kexidbcombobox.cpp
+++ b/kexi/plugins/forms/widgets/kexidbcombobox.cpp
@@ -62,7 +62,7 @@ class KexiDBComboBox::Private
TQSize sizeHint; //!< A cache for KexiDBComboBox::sizeHint(),
//!< rebuilt by KexiDBComboBox::fontChange() and KexiDBComboBox::styleChange()
KexiDB::QueryColumnInfo* visibleColumnInfo;
- TQPtrDict<char> *subWidgetsWithDisabledEvents; //! used to collect subwidget and its tqchildren (if isEditable is false)
+ TQPtrDict<char> *subWidgetsWithDisabledEvents; //! used to collect subwidget and its children (if isEditable is false)
bool isEditable : 1; //!< true is the combo box is editable
bool buttonPressed : 1;
bool mouseOver : 1;
@@ -259,7 +259,7 @@ bool KexiDBComboBox::handleMousePressEvent(TQMouseEvent *e)
if ( arrowRect.contains( e->pos() ) ) {
d->arrowPressed = TRUE;
d->arrowDown = TRUE;
- tqrepaint( FALSE );
+ repaint( FALSE );
}
} else {*/
showPopup();
diff --git a/kexi/plugins/forms/widgets/kexidbcombobox.h b/kexi/plugins/forms/widgets/kexidbcombobox.h
index dec6da1d..60ed78d1 100644
--- a/kexi/plugins/forms/widgets/kexidbcombobox.h
+++ b/kexi/plugins/forms/widgets/kexidbcombobox.h
@@ -111,7 +111,7 @@ class KEXIFORMUTILS_EXPORT KexiDBComboBox :
virtual bool eventFilter( TQObject *o, TQEvent *e );
- //! \return internal editor's tqgeometry
+ //! \return internal editor's geometry
TQRect editorGeometry() const;
//! Creates editor. Reimplemented, because if the combo box is not editable,
diff --git a/kexi/plugins/forms/widgets/kexidbimagebox.cpp b/kexi/plugins/forms/widgets/kexidbimagebox.cpp
index 3ff18406..5b8b2939 100644
--- a/kexi/plugins/forms/widgets/kexidbimagebox.cpp
+++ b/kexi/plugins/forms/widgets/kexidbimagebox.cpp
@@ -67,7 +67,7 @@ static TQPixmap* KexiDBImageBox_pmSmall = 0;
KexiDBImageBox::KexiDBImageBox( bool designMode, TQWidget *parent, const char *name )
: KexiFrame( parent, name, TQt::WNoAutoErase )
, KexiFormDataItemInterface()
- , m_tqalignment(TQt::AlignAuto|TQt::AlignTop)
+ , m_alignment(TQt::AlignAuto|TQt::AlignTop)
, m_designMode(designMode)
, m_readOnly(false)
, m_scaledContents(false)
@@ -176,7 +176,7 @@ void KexiDBImageBox::setValueInternal( const TQVariant& add, bool removeOld, boo
m_valueMimeType = TQString();
m_pixmap = TQPixmap();
}
- tqrepaint();
+ repaint();
}
void KexiDBImageBox::setInvalidState( const TQString& displayText )
@@ -242,7 +242,7 @@ void KexiDBImageBox::setPixmapId(uint id)
if (m_insideSetData) //avoid recursion
return;
setData(KexiBLOBBuffer::self()->objectForId( id, /*unstored*/false ));
- tqrepaint();
+ repaint();
}
uint KexiDBImageBox::storedPixmapId() const
@@ -257,7 +257,7 @@ uint KexiDBImageBox::storedPixmapId() const
void KexiDBImageBox::setStoredPixmapId(uint id)
{
setData(KexiBLOBBuffer::self()->objectForId( id, /*stored*/true ));
- tqrepaint();
+ repaint();
}
bool KexiDBImageBox::hasScaledContents() const
@@ -276,14 +276,14 @@ void KexiDBImageBox::setScaledContents(bool set)
{
//todo m_pixmapLabel->setScaledContents(set);
m_scaledContents = set;
- tqrepaint();
+ repaint();
}
void KexiDBImageBox::setKeepAspectRatio(bool set)
{
m_keepAspectRatio = set;
if (m_scaledContents)
- tqrepaint();
+ repaint();
}
TQWidget* KexiDBImageBox::widget()
@@ -331,7 +331,7 @@ void KexiDBImageBox::handleInsertFromFileAction(const KURL& url)
if (!h)
return;
setData(h);
- tqrepaint();
+ repaint();
}
else {
//db-aware
@@ -429,7 +429,7 @@ void KexiDBImageBox::handlePasteAction()
}
}
- tqrepaint();
+ repaint();
if (!dataSource().isEmpty()) {
// emit pixmapChanged();
signalValueChanged();
@@ -455,7 +455,7 @@ void KexiDBImageBox::clear()
//! @todo emit signal for setting "dirty" flag within the design
// m_pixmap = TQPixmap(); //will be loaded on demand
- tqrepaint();
+ repaint();
if (!dataSource().isEmpty()) {
// emit pixmapChanged();//valueChanged(data());
signalValueChanged();
@@ -573,7 +573,7 @@ void KexiDBImageBox::updateActionStrings()
(see doc/dev/settings.txt) */
beautifiedImageBoxName = beautifiedImageBoxName[0].upper() + beautifiedImageBoxName.mid(1);
}
- TQToolTip::add(m_chooser, i18n("Click to show actions for \"%1\" image box").tqarg(beautifiedImageBoxName));
+ TQToolTip::add(m_chooser, i18n("Click to show actions for \"%1\" image box").arg(beautifiedImageBoxName));
}
}
}
@@ -640,7 +640,7 @@ void KexiDBImageBox::paintEvent( TQPaintEvent *pe )
if (m_designMode && pixmap().isNull()) {
TQPixmap pm(size()-TQSize(m, m));
TQPainter p2;
- p2.tqbegin(TQT_TQPAINTDEVICE(&pm), this);
+ p2.begin(TQT_TQPAINTDEVICE(&pm), this);
p2.fillRect(0,0,width(),height(), bg);
updatePixmap();
@@ -678,7 +678,7 @@ void KexiDBImageBox::paintEvent( TQPaintEvent *pe )
//clearing needed here because we may need to draw a pixmap with transparency
p.fillRect(0,0,width(),height(), bg);
- KexiUtils::drawPixmap( p, m, TQRect(TQPoint(0,0), internalSize), pixmap(), m_tqalignment,
+ KexiUtils::drawPixmap( p, m, TQRect(TQPoint(0,0), internalSize), pixmap(), m_alignment,
m_scaledContents, m_keepAspectRatio );
}
KexiFrame::drawFrame( &p );
@@ -697,7 +697,7 @@ void KexiDBImageBox::paintEvent( TQPaintEvent *pe )
if (oldPalette.active().background()!=palette().active().background()) {
delete KexiDBImageBox_pm;
KexiDBImageBox_pm = 0;
- tqrepaint();
+ repaint();
}
}*/
@@ -715,11 +715,11 @@ void KexiDBImageBox::updatePixmap()
}
}
-void KexiDBImageBox::setAlignment(int tqalignment)
+void KexiDBImageBox::setAlignment(int alignment)
{
- m_tqalignment = tqalignment;
+ m_alignment = alignment;
if (!m_scaledContents || m_keepAspectRatio)
- tqrepaint();
+ repaint();
}
void KexiDBImageBox::setData(const KexiBLOBBuffer::Handle& handle)
@@ -839,7 +839,7 @@ bool KexiDBImageBox::eventFilter( TQObject * watched, TQEvent * e )
{
if (TQT_BASE_OBJECT(watched)==TQT_BASE_OBJECT(this) || TQT_BASE_OBJECT(watched)==TQT_BASE_OBJECT(m_chooser)) { //we're watching chooser as well because it's a focus proxy even if invisible
if (e->type()==TQEvent::FocusIn || e->type()==TQEvent::FocusOut || e->type()==TQEvent::MouseButtonPress) {
- update(); //to tqrepaint focus rect
+ update(); //to repaint focus rect
}
}
// hide popup menu as soon as it loses focus
diff --git a/kexi/plugins/forms/widgets/kexidbimagebox.h b/kexi/plugins/forms/widgets/kexidbimagebox.h
index a7adb3c8..860ee4c6 100644
--- a/kexi/plugins/forms/widgets/kexidbimagebox.h
+++ b/kexi/plugins/forms/widgets/kexidbimagebox.h
@@ -48,7 +48,7 @@ class KEXIFORMUTILS_EXPORT KexiDBImageBox :
TQ_PROPERTY( uint storedPixmapId READ storedPixmapId WRITE setStoredPixmapId DESIGNABLE false STORED true )
TQ_PROPERTY( bool scaledContents READ hasScaledContents WRITE setScaledContents )
TQ_PROPERTY( bool keepAspectRatio READ keepAspectRatio WRITE setKeepAspectRatio )
- TQ_PROPERTY( int tqalignment READ tqalignment WRITE setAlignment )
+ TQ_PROPERTY( int alignment READ alignment WRITE setAlignment )
// TQ_PROPERTY( TQString originalFileName READ originalFileName WRITE setOriginalFileName DESIGNABLE false )
// TQ_OVERRIDE( FocusPolicy focusPolicy READ focusPolicy WRITE setFocusPolicy )
TQ_PROPERTY( bool dropDownButtonVisible READ dropDownButtonVisible WRITE setDropDownButtonVisible )
@@ -95,7 +95,7 @@ class KEXIFORMUTILS_EXPORT KexiDBImageBox :
// bool designMode() const { return m_designMode; }
- int tqalignment() const { return m_tqalignment; }
+ int alignment() const { return m_alignment; }
bool keepAspectRatio() const { return m_keepAspectRatio; }
@@ -158,7 +158,7 @@ class KEXIFORMUTILS_EXPORT KexiDBImageBox :
void setScaledContents(bool set);
- void setAlignment(int tqalignment);
+ void setAlignment(int alignment);
void setKeepAspectRatio(bool set);
@@ -258,7 +258,7 @@ class KEXIFORMUTILS_EXPORT KexiDBImageBox :
//moved KAction *m_insertFromFileAction, *m_saveAsAction, *m_cutAction, *m_copyAction, *m_pasteAction,
// *m_deleteAction, *m_propertiesAction;
// TQTimer m_clickTimer;
- int m_tqalignment;
+ int m_alignment;
TQ_FocusPolicy m_focusPolicyInternal; //!< Used for focusPolicyInternal()
bool m_designMode : 1;
bool m_readOnly : 1;
diff --git a/kexi/plugins/forms/widgets/kexidblabel.cpp b/kexi/plugins/forms/widgets/kexidblabel.cpp
index 2f653f00..adb833fa 100644
--- a/kexi/plugins/forms/widgets/kexidblabel.cpp
+++ b/kexi/plugins/forms/widgets/kexidblabel.cpp
@@ -63,7 +63,7 @@ KexiDBInternalLabel::KexiDBInternalLabel( KexiDBLabel* parent )
: TQLabel( parent )
, m_parentLabel(parent)
{
- int a = tqalignment() | TQt::WordBreak;
+ int a = alignment() | TQt::WordBreak;
a &= (0xffffff ^ TQt::AlignVertical_Mask);
a |= TQt::AlignTop;
setAlignment( a );
@@ -426,7 +426,7 @@ void KexiDBLabel::init()
d->internalLabel->hide();
d->frameColor = tqpalette().active().foreground();
- setAlignment( d->internalLabel->tqalignment() );
+ setAlignment( d->internalLabel->alignment() );
}
void KexiDBLabel::updatePixmapLater() {
@@ -453,7 +453,7 @@ void KexiDBLabel::updatePixmap() {
d->internalLabel->setText( text() );
d->internalLabel->setFixedSize( size() );
d->internalLabel->setPalette( palette() );
- d->internalLabel->setAlignment( tqalignment() );
+ d->internalLabel->setAlignment( alignment() );
// d->shadowPixmap = KPixmap(); //parallel repaints won't hurt us cause incomplete pixmap
KPixmap shadowPixmap = d->internalLabel->getShadowPixmap();
if (shadowPixmap.isNull())
@@ -461,7 +461,7 @@ void KexiDBLabel::updatePixmap() {
d->shadowPixmap = shadowPixmap;
d->shadowPosition = d->internalLabel->m_shadowRect.topLeft();
d->pixmapDirty = false;
- tqrepaint();
+ repaint();
}
void KexiDBLabel::paintEvent( TQPaintEvent* e )
@@ -491,7 +491,7 @@ void KexiDBLabel::paintEvent( TQPaintEvent* e )
p.drawPixmap( d->internalLabel->m_shadowRect.topLeft(), d->shadowPixmap, clipRect );
}
}
- KexiDBTextWidgetInterface::paint( this, &p, text().isEmpty(), tqalignment(), false );
+ KexiDBTextWidgetInterface::paint( this, &p, text().isEmpty(), alignment(), false );
TQLabel::paintEvent( e );
}
@@ -577,7 +577,7 @@ void KexiDBLabel::setShadowEnabled( bool state ) {
d->pixmapDirty = true;
if (state)
d->internalLabel->updateFrame();
- tqrepaint();
+ repaint();
}
void KexiDBLabel::resizeEvent( TQResizeEvent* e ) {
@@ -636,7 +636,7 @@ void KexiDBLabel::setText( const TQString& text ) {
TQLabel::setText( text );
//This is necessary for KexiFormDataItemInterface
valueChanged();
- tqrepaint();
+ repaint();
}
bool KexiDBLabel::shadowEnabled() const
diff --git a/kexi/plugins/forms/widgets/kexidblineedit.cpp b/kexi/plugins/forms/widgets/kexidblineedit.cpp
index 5bb74e22..815adca9 100644
--- a/kexi/plugins/forms/widgets/kexidblineedit.cpp
+++ b/kexi/plugins/forms/widgets/kexidblineedit.cpp
@@ -331,14 +331,14 @@ void KexiDBLineEdit::setColumnInfo(KexiDB::QueryColumnInfo* cinfo)
/*todo
void KexiDBLineEdit::paint( TQPainter *p )
{
- KexiDBTextWidgetInterface::paint( this, &p, text().isEmpty(), tqalignment(), hasFocus() );
+ KexiDBTextWidgetInterface::paint( this, &p, text().isEmpty(), alignment(), hasFocus() );
}*/
void KexiDBLineEdit::paintEvent ( TQPaintEvent *pe )
{
KLineEdit::paintEvent( pe );
TQPainter p(this);
- KexiDBTextWidgetInterface::paint( this, &p, text().isEmpty(), tqalignment(), hasFocus() );
+ KexiDBTextWidgetInterface::paint( this, &p, text().isEmpty(), alignment(), hasFocus() );
}
bool KexiDBLineEdit::event( TQEvent * e )
diff --git a/kexi/plugins/forms/widgets/kexidbtextedit.cpp b/kexi/plugins/forms/widgets/kexidbtextedit.cpp
index c4cbe4d0..b6ab6b03 100644
--- a/kexi/plugins/forms/widgets/kexidbtextedit.cpp
+++ b/kexi/plugins/forms/widgets/kexidbtextedit.cpp
@@ -145,7 +145,7 @@ void KexiDBTextEdit::paintEvent ( TQPaintEvent *pe )
{
KTextEdit::paintEvent( pe );
TQPainter p(this);
- KexiDBTextWidgetInterface::paint( this, &p, text().isEmpty(), tqalignment(), hasFocus() );
+ KexiDBTextWidgetInterface::paint( this, &p, text().isEmpty(), alignment(), hasFocus() );
}
TQPopupMenu * KexiDBTextEdit::createPopupMenu(const TQPoint & pos)
diff --git a/kexi/plugins/forms/widgets/kexiframe.h b/kexi/plugins/forms/widgets/kexiframe.h
index 2f6ca562..ce51766c 100644
--- a/kexi/plugins/forms/widgets/kexiframe.h
+++ b/kexi/plugins/forms/widgets/kexiframe.h
@@ -53,7 +53,7 @@ class KEXIFORMUTILS_EXPORT KexiFrame : public TQFrame
GroupBoxPanel = TQFrame::GroupBoxPanel //!< rectangular group-box-like panel depending on the GUI style
};
Shape frameShape() const;
- void setFrameShape( KexiFrame::Shape tqshape );
+ void setFrameShape( KexiFrame::Shape shape );
Shadow frameShadow() const;
void setFrameShadow( KexiFrame::Shadow shadow );
#endif
diff --git a/kexi/plugins/forms/widgets/kexiframeutils_p.cpp b/kexi/plugins/forms/widgets/kexiframeutils_p.cpp
index 7adfbaa8..22a71001 100644
--- a/kexi/plugins/forms/widgets/kexiframeutils_p.cpp
+++ b/kexi/plugins/forms/widgets/kexiframeutils_p.cpp
@@ -69,9 +69,9 @@ ClassName::Shape ClassName::frameShape() const
return d->frameShape;
}
-void ClassName::setFrameShape( ClassName::Shape tqshape )
+void ClassName::setFrameShape( ClassName::Shape shape )
{
- d->frameShape = tqshape;
+ d->frameShape = shape;
update();
}
diff --git a/kexi/plugins/forms/kexiformscrollview.h b/kexi/plugins/forms/kexiformscrollview.h
index d8326a57..7d2b9867 100644
--- a/kexi/plugins/forms/kexiformscrollview.h
+++ b/kexi/plugins/forms/kexiformscrollview.h
@@ -162,17 +162,17 @@ class KEXIFORMUTILS_EXPORT KexiFormScrollView :
virtual void slotRowRepaintRequested(KexiTableItem& item);
//! Handles KexiTableViewData::aboutToDeleteRow() signal. Prepares info for slotRowDeleted().
- virtual void slotAboutToDeleteRow(KexiTableItem& item, KexiDB::ResultInfo* result, bool tqrepaint)
- { KexiDataAwareObjectInterface::slotAboutToDeleteRow(item, result, tqrepaint); }
+ virtual void slotAboutToDeleteRow(KexiTableItem& item, KexiDB::ResultInfo* result, bool repaint)
+ { KexiDataAwareObjectInterface::slotAboutToDeleteRow(item, result, repaint); }
- //! Handles KexiTableViewData::rowDeleted() signal to tqrepaint when needed.
+ //! Handles KexiTableViewData::rowDeleted() signal to repaint when needed.
virtual void slotRowDeleted() { KexiDataAwareObjectInterface::slotRowDeleted(); }
- //! Handles KexiTableViewData::rowInserted() signal to tqrepaint when needed.
- virtual void slotRowInserted(KexiTableItem *item, bool tqrepaint);
+ //! Handles KexiTableViewData::rowInserted() signal to repaint when needed.
+ virtual void slotRowInserted(KexiTableItem *item, bool repaint);
//! Like above, not db-aware version
- virtual void slotRowInserted(KexiTableItem *item, uint row, bool tqrepaint);
+ virtual void slotRowInserted(KexiTableItem *item, uint row, bool repaint);
virtual void slotRowsDeleted( const TQValueList<int> & );
@@ -193,7 +193,7 @@ class KEXIFORMUTILS_EXPORT KexiFormScrollView :
protected:
//! Implementation for KexiDataAwareObjectInterface
- virtual void clearColumnsInternal(bool tqrepaint);
+ virtual void clearColumnsInternal(bool repaint);
//! Implementation for KexiDataAwareObjectInterface
virtual void addHeaderColumn(const TQString& caption, const TQString& description,
diff --git a/kexi/plugins/forms/widgets/kexidbform.cpp b/kexi/plugins/forms/widgets/kexidbform.cpp
index bcf28a58..17242953 100644
--- a/kexi/plugins/forms/widgets/kexidbform.cpp
+++ b/kexi/plugins/forms/widgets/kexidbform.cpp
@@ -125,13 +125,13 @@ KexiDBForm::~KexiDBForm()
KexiDataAwareObjectInterface* KexiDBForm::dataAwareObject() const { return d->dataAwareObject; }
-//tqrepaint all tqchildren widgets
+//repaint all children widgets
static void repaintAll(TQWidget *w)
{
TQObjectList *list = w->queryList(TQWIDGET_OBJECT_NAME_STRING);
TQObjectListIt it(*list);
for (TQObject *obj; (obj=it.current()); ++it ) {
- TQT_TQWIDGET(obj)->tqrepaint();
+ TQT_TQWIDGET(obj)->repaint();
}
delete list;
}
@@ -148,7 +148,7 @@ void
KexiDBForm::drawRects(const TQValueList<TQRect> &list, int type)
{
TQPainter p;
- p.tqbegin(TQT_TQPAINTDEVICE(this), true);
+ p.begin(TQT_TQPAINTDEVICE(this), true);
bool unclipped = testWFlags( WPaintUnclipped );
setWFlags( WPaintUnclipped );
@@ -192,7 +192,7 @@ void
KexiDBForm::clearForm()
{
TQPainter p;
- p.tqbegin(TQT_TQPAINTDEVICE(this), true);
+ p.begin(TQT_TQPAINTDEVICE(this), true);
bool unclipped = testWFlags( WPaintUnclipped );
setWFlags( WPaintUnclipped );
@@ -216,7 +216,7 @@ KexiDBForm::highlightWidgets(TQWidget *from, TQWidget *to)//, const TQPoint &poi
toPoint = to->parentWidget()->mapTo(this, to->pos());
TQPainter p;
- p.tqbegin(TQT_TQPAINTDEVICE(this), true);
+ p.begin(TQT_TQPAINTDEVICE(this), true);
bool unclipped = testWFlags( WPaintUnclipped );
setWFlags( WPaintUnclipped );
@@ -234,7 +234,7 @@ KexiDBForm::highlightWidgets(TQWidget *from, TQWidget *to)//, const TQPoint &poi
TQPixmap pix2 = TQPixmap::grabWidget(to);
if((from != this) && (to != this))
- p.drawLine( from->parentWidget()->mapTo(this, from->tqgeometry().center()), to->parentWidget()->mapTo(this, to->tqgeometry().center()) );
+ p.drawLine( from->parentWidget()->mapTo(this, from->geometry().center()), to->parentWidget()->mapTo(this, to->geometry().center()) );
p.drawPixmap(fromPoint.x(), fromPoint.y(), pix1);
p.drawPixmap(toPoint.x(), toPoint.y(), pix2);
@@ -313,18 +313,18 @@ void KexiDBForm::updateTabStopsOrder(KFormDesigner::Form* form)
if (it.current()->widget()->focusPolicy() & TQ_TabFocus) {
//this widget has tab focus:
it.current()->widget()->installEventFilter(this);
- //also filter events for data-aware tqchildren of this widget (i.e. KexiDBAutoField's editors)
- TQObjectList *tqchildren = it.current()->widget()->queryList(TQWIDGET_OBJECT_NAME_STRING);
- for (TQObjectListIt tqchildrenIt(*tqchildren); tqchildrenIt.current(); ++tqchildrenIt) {
- // if (dynamic_cast<KexiFormDataItemInterface*>(tqchildrenIt.current())) {
+ //also filter events for data-aware children of this widget (i.e. KexiDBAutoField's editors)
+ TQObjectList *children = it.current()->widget()->queryList(TQWIDGET_OBJECT_NAME_STRING);
+ for (TQObjectListIt childrenIt(*children); childrenIt.current(); ++childrenIt) {
+ // if (dynamic_cast<KexiFormDataItemInterface*>(childrenIt.current())) {
kexipluginsdbg << "KexiDBForm::updateTabStopsOrder(): also adding '"
- << tqchildrenIt.current()->className() << " " << tqchildrenIt.current()->name()
+ << childrenIt.current()->className() << " " << childrenIt.current()->name()
<< "' child to filtered widgets" << endl;
- //it.current()->widget()->installEventFilter(TQT_TQWIDGET(tqchildrenIt.current()));
- tqchildrenIt.current()->installEventFilter(this);
+ //it.current()->widget()->installEventFilter(TQT_TQWIDGET(childrenIt.current()));
+ childrenIt.current()->installEventFilter(this);
// }
}
- delete tqchildren;
+ delete children;
if (fromWidget) {
kexipluginsdbg << "KexiDBForm::updateTabStopsOrder() tab order: " << fromWidget->name()
<< " -> " << it.current()->widget()->name() << endl;